sqlobject.tests.test_sqlobject_admin module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_sqlobject_admin module

class `sqlobject.tests.test_sqlobject_admin.` `SOTest1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test1
  `q` = so_test1
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `createSQL` = 'CREATE SEQUENCE db_test1_seq;'
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlobject_admin.SOTest1`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test1'
  property `test1`

class `sqlobject.tests.test_sqlobject_admin.` `SOTest2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test2
  `q` = so_test2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `createSQL` = ['CREATE SEQUENCE db_test2_seq;', "ALTER TABLE test2 ADD CHECK(test2 != '');"]
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlobject_admin.SOTest2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test2'
  property `test2`

class `sqlobject.tests.test_sqlobject_admin.` `SOTest3`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test3
  `q` = so_test3
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `createSQL` = {'mysql': 'CREATE SEQUENCE db_test3_seq;', 'postgres': 'CREATE SEQUENCE db_test3_seq;'}
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlobject_admin.SOTest3`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test3'
  property `test3`

class `sqlobject.tests.test_sqlobject_admin.` `SOTest4`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test4
  `q` = so_test4
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `createSQL` = {'mysql': 'CREATE SEQUENCE db_test4_seq;', 'postgres': ['CREATE SEQUENCE db_test4_seq;', "ALTER TABLE test4 ADD CHECK(test4 != '');"]}
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlobject_admin.SOTest4`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test4'
  property `test4`

class `sqlobject.tests.test_sqlobject_admin.` `SOTest5`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test5
  `q` = so_test5
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `createSQL` = {'mysql': 'CREATE SEQUENCE db_test5_seq;'}
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlobject_admin.SOTest5`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test5'
  property `test5`